﻿------------------------------------------------------------------------------------------
--Config UI-------------------------------------------------------------------------------
------------------------------------------------------------------------------------------
local SN, L, F, T, M, _ = unpack(select(2,...))
local LSM = LibStub("LibSharedMedia-3.0")

local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceDB = LibStub("AceDB-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")
local AceConfigRegistry = LibStub("AceConfigRegistry-3.0")

local selectedSpell

local function profileUpdate()
	db = SN.data.profile
end

function SN:Initialize()
	local db = AceDB:New("SNDB", SN.DB)
	SN.data = db
	SN.data.profile.classSelect.default = SN.playerClass
	SN:SetupConfig()
	SN:LoadConfig()
	
	
end

SN.TexCoords = {.08, .92, .08, .92}

function SN:LoadConfig()
	AceConfig:RegisterOptionsTable("SN", SN.options, nil)
	SN.options.args.profile = AceDBOptions:GetOptionsTable(SN.data)
		
	SN.optionsFrames = {}
	SN.optionsFrames.general = AceConfigDialog:AddToBlizOptions("SN", "Serenity Now", nil, "general")
	SN.optionsFrames.profile = AceConfigDialog:AddToBlizOptions("SN", "Profiles", "Serenity Now", "profile")

	SN.data.RegisterCallback(self, "OnProfileChanged", profileUpdate)
	SN.data.RegisterCallback(self, "OnProfileCopied", profileUpdate)
	SN.data.RegisterCallback(self, "OnProfileReset", profileUpdate)
end

function SN:SetupConfig()
local SNd = SN.data.profile
SN.options.args = {
	general = {
		type = "group",
		name = "general",
		args = {
			descrip = {
				order = 0,
				type = "description",
				name = L["A tool to have as much of the needed information from each class\nwithin eye sight so that you can say Serenity Now!"],
			},
			h1 = {
				order = 1,
				type = "header",
				name = "",
			},
				
			lock = {
				order = 2,
				name = L["Lock Frames"],
				type = 'toggle',
				get = function()
					return SNd.Frames.lock 
				end,
				set = function(key, value)
					--sn.db.profile.frames.lock = value
					SN:MoveFrames(value)
				end,
			},
			debug = {
				order = 2,
				name = L["Debug Mode"],
				type = "toggle",
				get = function()
					return SNd.debug.enable 
				end,
				set = function(key, value)
					SNd.debug.enable = value
				end,
			},
			configure = {
				order = 6,
				type = "execute",
				name = L["Apply Changes"],
				desc = L["Apply changes and reload the UI."],
				func = function()
					ReloadUI()
				end,
				order = 1,
				width = "normal",
			},
			h2 = {
				order = 7,
				type = "header",
				name = "",
			},
			cooldowns = {
				order = 24,
				type = "group",
				name = L["Cooldowns"],
				args = {
					enableall = {
						name = L["Enable All CD's"],
						type = "execute",
						order = 0,
						func = function()
							for i, cd in pairs(SNd.cooldowns) do
								cd.enable = true
							end
						end,
						width = "normal",
					},
					disableall = {
						name = L["Disable All CD's"],
						type = "execute",
						order = 1,
						func = function()
							for i, cd in pairs(SNd.cooldowns) do
								cd.enable = false
							end
						end,
						width = "normal",
					},
					castannounce = {
						type = "toggle",
						name = L["Announce Casts"],
						order = 2,
						get = function()
							return SNd.CD.castannounce
						end,
						set = function(key, value)
							SNd.CD.castannounce = value
						end,
					},
					raid = {
						order = 3,
						name = L["Show all CD's from the raid."],
						desc = L["Uncheck to show only your personal CD's."],
						type = "toggle",
						get = function()
							return SNd.CD.raid
						end,
						set = function(key, value)
							SNd.CD.raid = value
						end,
					},
					h3 = {
						order = 4,
						type = "header",
						name = "Dimensions",
					},
					cdwidth = {
						type = "range",
						name = L["Width of CD Bars"],
						order = 6,
						min = 50, max = 500, step = 1,
						get = function()
							return SNd.cooldown.width 
						end,
						set = function(info, value)
							SNd.cooldown.width = value
							F.cooldowns:SetWidth(value)
						end,
					},
					cdheight = {
						type = "range",
						name = L["Height of CD Bars"],
						order = 7,
						min = 12, max = 30, step = 1,
						get = function()
							return SNd.cooldown.height 
						end,
						set = function(info, value)
							SNd.cooldown.height = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetHeight(value)
								end
							end
						end,
					},
					h4 = {
						order = 8,
						type = "header",
						name = "Font",
					},
					cdfont = {
						type = "select",
						dialogControl = 'LSM30_Font',
						name = L["Font"],
						order = 10,
						values = AceGUIWidgetLSMlists.font,
						get = function() return SNd.cooldown.font end,--selectedClass end,
						set = function(info, value)
							SNd.cooldown.font = value
						end,
					},
					cdfontsize = {
						type = "range",
						name = L["Font Size of CD Bars"],
						order = 11,
						min = 10, max = 24, step = 1,
						get = function()
							return SNd.cooldown.fontsize 
						end,
						set = function(info, value)
							SNd.cooldown.fontsize = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i.FB_Duration:SetTextHeight(value)
									i.FB_Label:SetTextHeight(value)
								end
							end
						end,
					},
					
					h5 = {
						order = 12,
						type = "header",
						name = "",
					},
					cooldowns = {
						order = 0,
						type = "group",
						name = L["CD List"],
						args = {
							selectClass = {
								name = L["Select Class"],
								type = "select",
								order = 0,
								values = function()
									local values = { } 
									for _, class in pairs(CLASS_SORT_ORDER) do
										class1 = strsub(class, 1, 1)
										class1 = strconcat(class1, strlower(strsub(class, 2)))
										values[class] = class1
									end
									return values
								end,
								get = function(info) return SNd.classSelect.default end,--selectedClass end,
								set = function(info, value)
									--selectedClass = value
									SNd.classSelect.default = value
								end,
							},
							h6 = {
								order = 2,
								type = "header",
								name = "",
							},
							selectSpell = {
								name = L["Select Spell"],
								type = "multiselect",
								order = 4,						
								values = function()
									local values = {}
									for _, spell in pairs(SNd.cooldowns) do
										if SNd.classSelect.default == spell.class then--selectedClass == spell.class then
											local name, _, icon = GetSpellInfo(spell.id)
											values[spell.id] = name
										end
									end
									return values
								end,
								get = function(info, spid) 
									for _, spell in pairs(SNd.cooldowns) do
										if spid == spell.id then
											return spell.enable
										end
									end
								end,
								set = function(info, spid, value)
									for _, spell in pairs(SNd.cooldowns) do
										if spid == spell.id then
											spell.enable = value
										end
									end
								end,
							},
						},
					},
				},
			},
			debuffs = {
				order = 25,
				type = "group",
				name = L["Debuffs"],
				args = {
					dbenable = {
						type = "toggle",
						name = L["Enable Debuff Bars"],
						order = 0,
						get = function()
							return SNd.debuffs.enable
						end,
						set = function(key, value)
							SNd.debuffs.enable = value

							if value == true then
								SN:DebuffEnable()
							elseif value == false then
								SN:DebuffDisable()
							end
						end,
					},
					h7 = {
						order = 2,
						type = "header",
						name = "Dimensions",
					},
					dbwidth = {
						type = "range",
						name = L["Width of Debuff Bars"],
						order = 4,
						min = 50, max = 500, step = 1,
						get = function()
							return SNd.debuffs.width 
						end,
						set = function(info, value)
							SNd.debuffs.width = value
							F.debuffs:SetWidth(value)
						end,
					},
					dbheight = {
						type = "range",
						name = L["Height of Debuff Bars"],
						order = 5,
						min = 12, max = 30, step = 1,
						get = function()
							return SNd.debuffs.height 
						end,
						set = function(info, value)
							SNd.debuffs.height = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetHeight(value)
								end
							end
						end,
					},
					h8 = {
						order = 6,
						type = "header",
						name = "Font",
					},
					dbfont = {
						type = "select",
						dialogControl = 'LSM30_Font',
						name = L["Font"],
						order = 8,
						values = AceGUIWidgetLSMlists.font,
						get = function() return SNd.debuffs.font end,--selectedClass end,
						set = function(info, value)
							SNd.debuffs.font = value
						end,
					},
					dbfontsize = {
						type = "range",
						name = L["Font Size of Debuff Bars"],
						order = 9,
						min = 10, max = 24, step = 1,
						get = function()
							return SNd.debuffs.fontsize 
						end,
						set = function(info, value)
							SNd.debuffs.fontsize = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i.FB_Duration:SetTextHeight(value)
									i.FB_Label:SetTextHeight(value)
								end
							end
						end,
					},
				},
			},
			powerbar = {
				order = 24,
				type = "group",
				name = L["Powerbar"],
				args = {
					powenable = {
						order = 0,
						type = "toggle",
						name = L["Enable Powerbar"],
						get = function()
							return SNd.powerbar.enable
						end,
						set = function(key, value)
							if value == true then
								SN:PowerEnable()
							else
								SN:PowerDisable()
							end
							SNd.powerbar.enable = value
						end,
					},
					powertick = {
						order = 1,
						name = L["Powerbar Ticks Marks"],
						desc = L["Tick marks on the powerbar to represent how much power you need to cast your main spell."],
						type = "toggle",
						get = function()
							return SNd.powerbar.tickenable
						end,
						set = function(key, value)
							SNd.powerbar.tickenable = value
							SN:PowebarTicks()
						end,
					},
					h9 = {
						order = 2,
						type = "header",
						name = "Dimensions",
					},
					pbwidth = {
						type = "range",
						name = L["Width of Powerbar"],
						order = 4,
						min = 50, max = 500, step = 1,
						get = function()
							return SNd.powerbar.width 
						end,
						set = function(info, value)
							SNd.powerbar.width = value
							F.powercontainer:SetWidth(value)
							F.power:SetWidth(value)
						end,
					},
					pbheight = {
						type = "range",
						name = L["Height of Powerbar"],
						order = 5,
						min = 12, max = 30, step = 1,
						get = function()
							return SNd.powerbar.height 
						end,
						set = function(info, value)
							SNd.powerbar.height = value
							F.powercontainer:SetHeight(value)
							F.power:SetHeight(value)
						end,
					},
					h10 = {
						order = 6,
						type = "header",
						name = "Font",
					},
					pbfont = {
						type = "select",
						dialogControl = 'LSM30_Font',
						name = L["Font"],
						order = 8,
						values = AceGUIWidgetLSMlists.font,
						get = function() return SNd.powerbar.font end,--selectedClass end,
						set = function(info, value)
							SNd.powerbar.font = value
						end,
					},
					pbfontsize = {
						type = "range",
						name = L["Font Size of Powerbar"],
						order = 9,
						min = 10, max = 24, step = 1,
						get = function()
							return SNd.powerbar.fontsize 
						end,
						set = function(info, value)
							SNd.powerbar.fontsize = value
							F.power.value:SetFont(LSM.media.font, SNd.powerbar.fontsize, "OUTLINE")
						end,
					},
				},
			},
			ClassPower = {
				order = 25,
				type = "group",
				name = L["Class Power"],
				args = {
					classenable = {
						order = 0,
						type = "toggle",
						name = L["Enable Class Power"],
						get = function()
							return SNd.classResources.enable
						end,
						set = function(key, value)
							if value == true then
								SN:ClassEnable()
							else
								SN:ClassDisable()
							end
							SNd.classResources.enable = value
						end,
					},
				},
			},
			dispel = {
				order = 26,
				type = "group",
				name = L["Dispel"],
				args = {
					dispelenable = {
						type = "toggle",
						name = L["Enable Dispel System"],
						order = 0,
						get = function()
							return SNd.dispel.enable
						end,
						set = function(key, value)
							if value == true then
								F.dispel:Show()
							else
								F.dispel:Hide()
							end
							SNd.dispel.enable = value
						end,
					},
				},
			},
		},
	},
}

end

				
				--threat = {
				--	order = 26,
				--	type = "group",
				--	name = L["Threat"],
				--	args = { 
				--		threatenable = {
				--			type = "toggle",
				--			name = L["Enable Threat System"],
				--			order = 0,
				--			get = function()
				--				return SN.db.profile.threat.enable
				--			end,
				--			set = function(key, value)
				--				if value == true then
				--					SN.F.threat:Show()
				--				else
				--					SN.F.threat:Hide()
				--				end
				--				SN.db.profile.threat.enable = value
				--			end,
				--		},
				--	},
				--},
				
				
	